/*
 * This file is part of KMyMoney, A Personal Finance Manager by KDE
 * Copyright (C) 2015 Christian Dávid <christian-david@web.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHARVALIDATOR_H
#define CHARVALIDATOR_H

#include <QValidator>

class charValidator : public QValidator
{
  Q_OBJECT

public:
  explicit charValidator(QObject* parent = 0, const QString& characters = QString());
  QValidator::State validate(QString& , int&) const final override;

  void setAllowedCharacters(const QString&);

private:
  QString m_allowedCharacters;
};

#endif // CHARVALIDATOR_H
